@@ -33,11 +33,6 @@
 
 #include <Rcpp.h>
 
-void R_init_osmdata(DllInfo* info) {
-    R_registerRoutines(info, NULL, NULL, NULL, NULL);
-    R_useDynamicSymbols(info, TRUE);
-}
-
 
 /************************************************************************
  ************************************************************************
